@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from .mixins import OrderingMixin
 from AccessControl import getSecurityManager
 from plone.autoform.interfaces import WRITE_PERMISSIONS_KEY
@@ -84,6 +83,7 @@ class DeserializeFromJson(OrderingMixin, object):
             write_permissions = mergedTaggedValueDict(schema, WRITE_PERMISSIONS_KEY)
 
             for name, field in getFields(schema).items():
+                __traceback_info__ = "field={}".format(field)
 
                 field_data = schema_data.setdefault(schema, {})
 
