@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 from plone.folder.interfaces import IExplicitOrdering
+from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.interfaces.siteroot import IPloneSiteRoot
 from zExceptions import BadRequest
 
@@ -21,6 +21,12 @@ class OrderingMixin(object):
 
             self.reorderItems(obj_id, delta, subset_ids)
 
+        if "sort" in data:
+            # resort folder items with given parameters
+            sort_on = data["sort"]["on"]
+            sort_order = data["sort"]["order"]
+            self.resortAllItemsInContext(sort_on, sort_order)
+
     def reorderItems(self, obj_id, delta, subset_ids):
         # Based on wildcard.foldercontents.viewsItemOrder
         ordering = self.getOrdering()
@@ -54,11 +60,29 @@ class OrderingMixin(object):
             delta = int(delta)
             ordering.moveObjectsByDelta([obj_id], delta, subset_ids=subset_ids)
 
+    def resortAllItemsInContext(self, sort_on, sort_order):
+        # Based on plone.app.content.browser.contents.rearrange
+        ordering = self.getOrdering()
+        if ordering is None:
+            msg = "Content ordering is not supported by this resource"
+            raise BadRequest(msg)
+
+        catalog = getToolByName(self.context, "portal_catalog")
+        query = {
+            "path": {"query": "/".join(self.context.getPhysicalPath()), "depth": 1},
+            "sort_on": sort_on,
+            "show_inactive": True,
+        }
+        brains = catalog(**query)
+        if sort_order in ("reverse", "descending"):
+            brains = [b for b in reversed(brains)]
+        for idx, brain in enumerate(brains):
+            ordering.moveObjectToPosition(brain.id, idx)
+
     def getOrdering(self):
         if IPloneSiteRoot.providedBy(self.context):
             return self.context
-        elif getattr(self.context, "getOrdering", None):
+        if getattr(self.context, "getOrdering", None):
             ordering = self.context.getOrdering()
-            if not IExplicitOrdering.providedBy(ordering):
-                return None
-            return ordering
+            if IExplicitOrdering.providedBy(ordering):
+                return ordering
