@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from AccessControl.requestmethod import postonly
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from BTrees.OIBTree import OIBTree
@@ -7,6 +6,8 @@ from datetime import datetime
 from datetime import timedelta
 from plone.keyring.interfaces import IKeyManager
 from plone.keyring.keyring import GenerateSecret
+from plone.restapi import exceptions
+from plone.restapi import deserializer
 from Products.CMFCore.permissions import ManagePortal
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 from Products.PluggableAuthService.interfaces.plugins import IAuthenticationPlugin
@@ -63,9 +64,8 @@ class JWTAuthenticationPlugin(BasePlugin):
         self._setId(id_)
         self.title = title
 
-    security.declarePrivate("challenge")
-
     # Initiate a challenge to the user to provide credentials.
+    @security.private
     def challenge(self, request, response, **kw):
 
         realm = response.realm
@@ -77,37 +77,46 @@ class JWTAuthenticationPlugin(BasePlugin):
         response.setStatus(401)
         return True
 
-    security.declarePrivate("extractCredentials")
-
     # IExtractionPlugin implementation
     # Extracts a JSON web token from the request.
+    @security.private
     def extractCredentials(self, request):
+        """
+        Extract credentials either from a JSON POST request or an established JWT token.
+        """
+        # Prefer any credentials in a JSON POST request under the assumption that any
+        # such requested sent when a JWT token is already in the `Authorization` header
+        # is intended to change or update the logged in user.
+        try:
+            creds = deserializer.json_body(request)
+        except exceptions.DeserializationError:
+            pass
+        else:
+            if "login" in creds and "password" in creds:
+                return creds
+
         creds = {}
         auth = request._auth
         if auth is None:
-            return None
+            return
         if auth[:7].lower() == "bearer ":
             creds["token"] = auth.split()[-1]
-        else:
-            return None
-
-        return creds
-
-    security.declarePrivate("authenticateCredentials")
+            return creds
 
     # IAuthenticationPlugin implementation
+    @security.private
     def authenticateCredentials(self, credentials):
         # Ignore credentials that are not from our extractor
         extractor = credentials.get("extractor")
         if extractor != self.getId():
-            return None
+            return
 
         payload = self._decode_token(credentials["token"])
         if not payload:
-            return None
+            return
 
         if "sub" not in payload:
-            return None
+            return
 
         userid = payload["sub"]
         if six.PY2:
@@ -115,14 +124,13 @@ class JWTAuthenticationPlugin(BasePlugin):
 
         if self.store_tokens:
             if userid not in self._tokens:
-                return None
+                return
             if credentials["token"] not in self._tokens[userid]:
-                return None
+                return
 
         return (userid, userid)
 
-    security.declareProtected(ManagePortal, "manage_updateConfig")
-
+    @security.protected(ManagePortal)
     @postonly
     def manage_updateConfig(self, REQUEST):
         """Update configuration of JWT Authentication Plugin."""
@@ -157,7 +165,7 @@ class JWTAuthenticationPlugin(BasePlugin):
         try:
             return jwt.decode(token, secret, verify=verify, algorithms=["HS256"])
         except jwt.InvalidTokenError:
-            return None
+            pass
 
     def _signing_secret(self):
         if self.use_keyring:
