@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 The adapters in this module are responsible for turning back a catalog query
 that has been serialized (to a HTTP query string or JSON) into a query that is
@@ -76,6 +75,8 @@ class ZCatalogCompatibleQueryAdapter(object):
         "b_size": int,
     }
 
+    ignore_query_params = ["metadata_fields"]
+
     def __init__(self, context, request):
         self.context = context
         self.request = request
@@ -100,7 +101,8 @@ class ZCatalogCompatibleQueryAdapter(object):
             # that could not be serialized in a query string or JSON
             index = self.get_index(idx_name)
             if index is None:
-                log.warn("No such index: %r" % idx_name)
+                if idx_name not in self.ignore_query_params:
+                    log.warning("No such index: %r" % idx_name)
                 continue
 
             query_opts_parser = getMultiAdapter(
@@ -174,7 +176,7 @@ class BaseIndexQueryParser(object):
                         " casted to %r" % (opt_value, opt_key, self.index, opt_type)
                     )
             else:
-                log.warn(
+                log.warning(
                     "Unrecognized query option %r for index %r" % (opt_key, self.index)
                 )
                 # Pass along unknown option without modification
