@@ -1,8 +1,9 @@
-# -*- coding: utf-8 -*-
 from copy import deepcopy
 from plone.outputfilters.browser.resolveuid import uuidToObject
 from plone.outputfilters.browser.resolveuid import uuidToURL
 from plone.restapi.behaviors import IBlocks
+from plone.restapi.deserializer.blocks import SlateBlockTransformer
+from plone.restapi.deserializer.blocks import transform_links
 from plone.restapi.interfaces import IBlockFieldSerializationTransformer
 from plone.restapi.interfaces import IFieldSerializer
 from plone.restapi.interfaces import IObjectPrimaryFieldTarget
@@ -161,22 +162,52 @@ class TextBlockSerializerBase(object):
 @implementer(IBlockFieldSerializationTransformer)
 @adapter(IBlocks, IBrowserRequest)
 class ResolveUIDSerializer(ResolveUIDSerializerBase):
-    """ Serializer for content-types with IBlocks behavior """
+    """Serializer for content-types with IBlocks behavior"""
 
 
 @implementer(IBlockFieldSerializationTransformer)
 @adapter(IPloneSiteRoot, IBrowserRequest)
 class ResolveUIDSerializerRoot(ResolveUIDSerializerBase):
-    """ Serializer for site root """
+    """Serializer for site root"""
 
 
 @implementer(IBlockFieldSerializationTransformer)
 @adapter(IBlocks, IBrowserRequest)
 class TextBlockSerializer(TextBlockSerializerBase):
-    """ Serializer for content-types with IBlocks behavior """
+    """Serializer for content-types with IBlocks behavior"""
 
 
 @implementer(IBlockFieldSerializationTransformer)
 @adapter(IPloneSiteRoot, IBrowserRequest)
 class TextBlockSerializerRoot(TextBlockSerializerBase):
-    """ Serializer for site root """
+    """Serializer for site root"""
+
+
+class SlateBlockSerializerBase(SlateBlockTransformer):
+    """SlateBlockSerializerBase."""
+
+    order = 100
+    block_type = "slate"
+    disabled = os.environ.get("disable_transform_resolveuid", False)
+
+    def _uid_to_url(self, context, path):
+        return uid_to_url(path)
+
+    def handle_a(self, child):
+        transform_links(self.context, child, transformer=self._uid_to_url)
+
+    def handle_link(self, child):
+        if child.get("data", {}).get("url"):
+            child["data"]["url"] = uid_to_url(child["data"]["url"])
+
+
+@implementer(IBlockFieldSerializationTransformer)
+@adapter(IBlocks, IBrowserRequest)
+class SlateBlockSerializer(SlateBlockSerializerBase):
+    """Serializer for content-types with IBlocks behavior"""
+
+
+@implementer(IBlockFieldSerializationTransformer)
+@adapter(IPloneSiteRoot, IBrowserRequest)
+class SlateBlockSerializerRoot(SlateBlockSerializerBase):
+    """Serializer for site root"""
