@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 from plone.restapi.batching import HypermediaBatch
+from plone.restapi.interfaces import IBlockFieldSerializationTransformer
 from plone.restapi.interfaces import ISerializeToJson
 from plone.restapi.interfaces import ISerializeToJsonSummary
 from plone.restapi.serializer.expansion import expandable_elements
@@ -7,6 +7,7 @@ from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.interfaces import IPloneSiteRoot
 from zope.component import adapter
 from zope.component import getMultiAdapter
+from zope.component import subscribers
 from zope.interface import implementer
 from zope.interface import Interface
 
@@ -49,7 +50,7 @@ class SerializeSiteRootToJson(object):
             "parent": {},
             "is_folderish": True,
             "description": self.context.description,
-            "blocks": json.loads(getattr(self.context, "blocks", "{}")),
+            "blocks": self.serialize_blocks(),
             "blocks_layout": json.loads(
                 getattr(self.context, "blocks_layout", "{}")
             ),  # noqa
@@ -68,3 +69,23 @@ class SerializeSiteRootToJson(object):
         ]
 
         return result
+
+    def serialize_blocks(self):
+        blocks = json.loads(getattr(self.context, "blocks", "{}"))
+        if not blocks:
+            return blocks
+        for id, block_value in blocks.items():
+            block_type = block_value.get("@type", "")
+            handlers = []
+            for h in subscribers(
+                (self.context, self.request), IBlockFieldSerializationTransformer
+            ):
+                if h.block_type == block_type or h.block_type is None:
+                    handlers.append(h)
+
+            for handler in sorted(handlers, key=lambda h: h.order):
+                if not getattr(handler, "disabled", False):
+                    block_value = handler(block_value)
+
+            blocks[id] = block_value
+        return blocks
