@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from Acquisition import aq_inner
 from Acquisition import aq_parent
 from plone.restapi.pas.plugin import JWTAuthenticationPlugin
@@ -15,9 +14,10 @@ class HiddenProfiles(object):
     def getNonInstallableProfiles(self):  # pragma: no cover
         """Do not show on Plone's list of installable profiles."""
         return [
+            u"plone.restapi:blocks",
             u"plone.restapi:performance",
             u"plone.restapi:testing",
-            u"plone.restapi:blocks",
+            u"plone.restapi:testing-workflows",
             u"plone.restapi:uninstall",
         ]
 
@@ -46,8 +46,7 @@ def install_pas_plugin(context):
 
 
 def import_various(context):
-    """Miscellanous steps import handle
-    """
+    """Miscellanous steps import handle"""
     if context.readDataFile("plone.restapi_various.txt") is None:
         return
 
