@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from datetime import date
 from datetime import datetime
 from datetime import time
@@ -22,8 +21,7 @@ import unittest
 
 
 class RequiredField(object):
-    """Context manager that will make a field required and back to old state.
-    """
+    """Context manager that will make a field required and back to old state."""
 
     def __init__(self, field):
         self.field = field
@@ -177,10 +175,10 @@ class TestDXFieldDeserializer(unittest.TestCase):
             with self.assertRaises(RequiredMissing):
                 self.deserialize(field_name, None)
 
-    def test_decimal_deserialization_returns_decimal(self):
+    def test_text_deserialization_returns_decimal(self):
         value = self.deserialize("test_decimal_field", u"1.1")
         self.assertTrue(isinstance(value, Decimal), "Not a <Decimal>")
-        self.assertEqual(Decimal("1.1"), value)
+        self.assertEqual(Decimal(u"1.1"), value)
 
     def test_dict_deserialization_returns_dict(self):
         value = self.deserialize("test_dict_field", {u"key": u"value"})
@@ -606,3 +604,26 @@ class TestDXFieldDeserializer(unittest.TestCase):
             deserializer(b"not an int")
 
         self.assertEqual(42, deserializer(42))
+
+    def test_textline_deserializer_for_links_convert_internal_links(self):
+        self.portal.invokeFactory("Link", id="link", title="Test Link")
+        link = self.portal.link
+        field = None
+        for schema in iterSchemata(link):
+            if "remoteUrl" in schema:
+                field = schema.get("remoteUrl")
+                break
+        deserializer = getMultiAdapter((field, link, self.request), IFieldDeserializer)
+
+        self.assertEqual(
+            u"http://www.plone.com", deserializer(value=u"http://www.plone.com")
+        )
+        self.assertEqual(
+            u"${portal_url}/doc1", deserializer(value=u"http://nohost/plone/doc1")
+        )
+
+        # for other contents/fields does nothing
+        value = self.deserialize("test_textline_field", u"http://www.plone.com")
+        self.assertEqual(u"http://www.plone.com", value)
+        value = self.deserialize("test_textline_field", u"http://nohost/plone/doc1")
+        self.assertEqual(self.portal.doc1.absolute_url(), value)
