@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from pkg_resources import get_distribution
 from pkg_resources import parse_version
 from plone.app.testing import setRoles
@@ -167,3 +166,98 @@ class TestQuerystringSearchEndpoint(unittest.TestCase):
             response.json()["items"][0]["@id"],
             "{}/testdocument2".format(self.portal.absolute_url()),
         )
+
+    def test_querystringsearch_sort(self):
+        # id: testdocument1, title: Test I Document 1
+        # id: testdocument2, title: Test H Document 2
+        # ...
+        # id: testdocument9, title: Test A Document 9
+        for a in range(1, 10):
+            self.portal.invokeFactory(
+                "Document",
+                "testdocument" + str(a),
+                title="Test " + "ABCDEFGHI"[-a] + " Document " + str(a),
+            )
+        transaction.commit()
+
+        query = [
+            {
+                "i": "portal_type",
+                "o": "plone.app.querystring.operation.selection.is",
+                "v": ["Document"],
+            }
+        ]
+        # default order 'ascending'
+        response = self.api_session.post(
+            "/@querystring-search",
+            json={
+                "query": query,
+                "sort_on": "sortable_title",
+            },
+        )
+        self.assertEqual(response.json()["items_total"], 10)
+        self.assertEqual(
+            response.json()["items"][0]["title"],
+            "Test A Document 9",
+        )
+        self.assertEqual(
+            response.json()["items"][-1]["title"],
+            "Test I Document 1",
+        )
+
+        # force order 'ascending'
+        response = self.api_session.post(
+            "/@querystring-search",
+            json={
+                "query": query,
+                "sort_on": "sortable_title",
+                "sort_order": "ascending",
+            },
+        )
+        self.assertEqual(response.json()["items_total"], 10)
+        self.assertEqual(
+            response.json()["items"][0]["title"],
+            "Test A Document 9",
+        )
+        self.assertEqual(
+            response.json()["items"][-1]["title"],
+            "Test I Document 1",
+        )
+
+        # force order 'descending'
+        response = self.api_session.post(
+            "/@querystring-search",
+            json={
+                "query": query,
+                "sort_on": "sortable_title",
+                "sort_order": "descending",
+            },
+        )
+        self.assertEqual(response.json()["items_total"], 10)
+        self.assertEqual(
+            response.json()["items"][0]["title"],
+            "Test I Document 1",
+        )
+        self.assertEqual(
+            response.json()["items"][-1]["title"],
+            "Test A Document 9",
+        )
+
+        # sort by id, 'ascending'
+        response = self.api_session.post(
+            "/@querystring-search",
+            json={
+                "query": query,
+                "sort_on": "getId",
+                "sort_order": "ascending",
+            },
+        )
+        self.assertEqual(response.json()["items_total"], 10)
+        self.assertEqual(
+            response.json()["items"][0]["@id"],
+            "{}/testdocument".format(self.portal.absolute_url()),
+        )
+        self.assertEqual(
+            response.json()["items"][-1]["@id"],
+            "{}/testdocument9".format(self.portal.absolute_url()),
+        )
