@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.restapi.interfaces import ISerializeToJson
 from plone.restapi.testing import PLONE_RESTAPI_DX_INTEGRATION_TESTING
 from zope.component import getMultiAdapter
@@ -15,6 +14,11 @@ class TestSiteSerializer(unittest.TestCase):
         self.portal = self.layer["portal"]
         self.request = self.layer["request"]
 
+        self.portal.invokeFactory(
+            "Document",
+            id=u"doc1",
+        )
+
     def serialize(self):
         serializer = getMultiAdapter((self.portal, self.request), ISerializeToJson)
         return serializer()
@@ -32,3 +36,18 @@ class TestSiteSerializer(unittest.TestCase):
         obj = self.serialize()
         self.assertIn("is_folderish", obj)
         self.assertEqual(True, obj["is_folderish"])
+
+    def test_resolveuids_get_serialized_in_serializer(self):
+        blocks = {
+            "0358abe2-b4f1-463d-a279-a63ea80daf19": {
+                "@type": "foo",
+                "url": "resolveuid/{}".format(self.portal.doc1.UID()),
+            },
+            "07c273fc-8bfc-4e7d-a327-d513e5a945bb": {"@type": "title"},
+        }
+        self.portal.blocks = json.dumps(blocks)
+        obj = self.serialize()
+        self.assertEqual(
+            obj["blocks"]["0358abe2-b4f1-463d-a279-a63ea80daf19"]["url"],
+            self.portal.doc1.absolute_url(),
+        )
