@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.testing import setRoles
 from plone.app.testing import TEST_USER_ID
 from plone.restapi.testing import PLONE_RESTAPI_DX_INTEGRATION_TESTING
@@ -36,7 +35,12 @@ class TestUpgradeOrdering(unittest.TestCase):
         ensure_child_ordering_object_ids_are_native_strings(self.folder)
 
         self.assertEqual(
-            ["doc2", "doc3", "doc1",], self.folder.objectIds(),  # noqa
+            [
+                "doc2",
+                "doc3",
+                "doc1",
+            ],
+            self.folder.objectIds(),  # noqa
         )
 
         # upgrade helper should ensure bytestring ids in python2 and do nothing
@@ -61,7 +65,12 @@ class TestUpgradeOrdering(unittest.TestCase):
         view()
 
         self.assertEqual(
-            ["doc2", "doc3", "doc1",], self.folder.objectIds(),  # noqa
+            [
+                "doc2",
+                "doc3",
+                "doc1",
+            ],
+            self.folder.objectIds(),  # noqa
         )
 
         # upgrade helper should ensure bytestring ids in python2 and do nothing
