@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """JsonSchema providers."""
 from plone.app.textfield.interfaces import IRichText
 from plone.restapi.types.interfaces import IJsonSchemaProvider
@@ -94,10 +93,10 @@ class DefaultJsonSchemaProvider(object):
         raise NotImplementedError
 
     def get_factory(self):
-        return None
+        pass
 
     def get_widget(self):
-        return None
+        return getattr(self.field, "widget", None)
 
     def get_widget_params(self):
         all_params = get_widget_params([self.field.interface])
@@ -432,7 +431,7 @@ class DictJsonSchemaProvider(DefaultJsonSchemaProvider):
             "additional": key_type.additional(),
         }
         value_type = getMultiAdapter(
-            (self.field.key_type, self.context, self.request), IJsonSchemaProvider
+            (self.field.value_type, self.context, self.request), IJsonSchemaProvider
         )
         info["value_type"] = {
             "schema": value_type.get_schema(),
